You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@syncope.apache.org by il...@apache.org on 2012/11/12 12:53:38 UTC

svn commit: r1408258 - in /incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src: main/java/org/apache/syncope/core/init/ main/java/org/apache/syncope/core/policy/ main/java/org/apache/syncope/core/rest/controller/ main/java/org/apache/syncope/core...

Author: ilgrosso
Date: Mon Nov 12 11:53:36 2012
New Revision: 1408258

URL: http://svn.apache.org/viewvc?rev=1408258&view=rev
Log:
[SYNCOPE-173][SYNCOPE-219] (Additional) Moving some classes to new packages as preparation for role-related workflow classes

Modified:
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/ContentLoader.java
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/SpringContextInitializer.java
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/policy/AccountPolicyEnforcer.java
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/UserController.java
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/WorkflowController.java
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/sync/SyncopeSyncResultHanlder.java
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflow.properties
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflowContext.xml
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflow.properties
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflowContext.xml
    incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/workflow.properties

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/ContentLoader.java
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/ContentLoader.java?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/ContentLoader.java (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/ContentLoader.java Mon Nov 12 11:53:36 2012
@@ -156,7 +156,7 @@ public class ContentLoader {
             LOG.error("While creating indexes", e);
         }
 
-        // Can't test wfAdapter.getClass() because it is @Autowired
+        // Can't test uwfAdapter.getClass() because it is @Autowired
         if (SpringContextInitializer.isActivitiConfigured()) {
             try {
                 statement = conn.prepareStatement("DELETE FROM ACT_GE_PROPERTY");

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/SpringContextInitializer.java
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/SpringContextInitializer.java?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/SpringContextInitializer.java (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/init/SpringContextInitializer.java Mon Nov 12 11:53:36 2012
@@ -22,8 +22,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.Properties;
 import javax.servlet.ServletContext;
-import org.apache.syncope.core.workflow.user.activiti.ActivitiUserWorkflowAdapter;
 import org.apache.syncope.core.workflow.user.UserWorkflowAdapter;
+import org.apache.syncope.core.workflow.user.activiti.ActivitiUserWorkflowAdapter;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.BeansException;
@@ -47,13 +47,13 @@ public class SpringContextInitializer im
      */
     private static final Logger LOG = LoggerFactory.getLogger(SpringContextInitializer.class);
 
-    private static String wfAdapterClassName;
+    private static String uwfAdapterClassName;
 
     static {
         try {
-            initWFAdapterClassName();
+            initUWFAdapterClassName();
         } catch (IOException e) {
-            LOG.error("Could not init wfAdapterClassName", e);
+            LOG.error("Could not init uwfAdapterClassName", e);
         }
     }
 
@@ -62,13 +62,13 @@ public class SpringContextInitializer im
      *
      * @throws IOException if anything goes wrong
      */
-    public static void initWFAdapterClassName() throws IOException {
+    public static void initUWFAdapterClassName() throws IOException {
         Properties props = new java.util.Properties();
         InputStream propStream = null;
         try {
             propStream = ContentLoader.class.getResourceAsStream("/workflow.properties");
             props.load(propStream);
-            wfAdapterClassName = props.getProperty("wfAdapter");
+            uwfAdapterClassName = props.getProperty("uwfAdapter");
         } catch (Exception e) {
             LOG.error("Could not load workflow.properties", e);
         } finally {
@@ -84,7 +84,7 @@ public class SpringContextInitializer im
      * @return whether Activiti is configured for workflow or not
      */
     public static boolean isActivitiConfigured() {
-        return wfAdapterClassName != null && wfAdapterClassName.equals(ActivitiUserWorkflowAdapter.class.getName());
+        return uwfAdapterClassName != null && uwfAdapterClassName.equals(ActivitiUserWorkflowAdapter.class.getName());
     }
 
     @Autowired
@@ -97,7 +97,7 @@ public class SpringContextInitializer im
     private JobInstanceLoader jobInstanceLoader;
 
     @Autowired
-    private UserWorkflowAdapter wfAdapter;
+    private UserWorkflowAdapter uwfAdapter;
 
     @Autowired
     private LoggerLoader loggerLoader;
@@ -124,9 +124,9 @@ public class SpringContextInitializer im
         loggerLoader.load();
         classNamesLoader.load();
 
-        if (wfAdapter.getLoaderClass() != null) {
+        if (uwfAdapter.getLoaderClass() != null) {
             final WorkflowLoader wfLoader = (WorkflowLoader) beanFactory.createBean(
-                    wfAdapter.getLoaderClass(), AbstractBeanDefinition.AUTOWIRE_BY_TYPE, false);
+                    uwfAdapter.getLoaderClass(), AbstractBeanDefinition.AUTOWIRE_BY_TYPE, false);
             wfLoader.load();
         }
     }

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/policy/AccountPolicyEnforcer.java
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/policy/AccountPolicyEnforcer.java?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/policy/AccountPolicyEnforcer.java (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/policy/AccountPolicyEnforcer.java Mon Nov 12 11:53:36 2012
@@ -39,7 +39,7 @@ import org.springframework.stereotype.Co
 public class AccountPolicyEnforcer extends PolicyEnforcer<AccountPolicySpec, SyncopeUser> {
 
     @Autowired
-    private UserWorkflowAdapter wfAdapter;
+    private UserWorkflowAdapter uwfAdapter;
 
     @Autowired
     private PropagationManager propagationManager;
@@ -116,7 +116,7 @@ public class AccountPolicyEnforcer exten
                 user.setFailedLogins(user.getFailedLogins() - 1);
 
                 // disable user
-                final WorkflowResult<Long> updated = wfAdapter.suspend(user);
+                final WorkflowResult<Long> updated = uwfAdapter.suspend(user);
 
                 // propagate suspension if and only if it is required by policy
                 if (policy.isPropagateSuspension()) {

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/UserController.java
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/UserController.java?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/WorkflowController.java (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/WorkflowController.java Mon Nov 12 11:53:36 2012
@@ -44,14 +44,14 @@ public class WorkflowController extends 
     private AuditManager auditManager;
 
     @Autowired
-    private UserWorkflowAdapter wfAdapter;
+    private UserWorkflowAdapter uwfAdapter;
 
     @PreAuthorize("hasRole('WORKFLOW_DEF_READ')")
     @RequestMapping(method = RequestMethod.GET, value = "/definition")
     @Transactional(readOnly = true)
     public WorkflowDefinitionTO getDefinition() throws WorkflowException {
 
-        WorkflowDefinitionTO result = wfAdapter.getDefinition();
+        WorkflowDefinitionTO result = uwfAdapter.getDefinition();
 
         auditManager.audit(Category.workflow, WorkflowSubCategory.getDefinition, Result.success,
                 "Successfully got workflow definition");
@@ -64,7 +64,7 @@ public class WorkflowController extends 
     public void updateDefinition(@RequestBody final WorkflowDefinitionTO definition)
             throws NotFoundException, WorkflowException {
 
-        wfAdapter.updateDefinition(definition);
+        uwfAdapter.updateDefinition(definition);
 
         auditManager.audit(Category.workflow, WorkflowSubCategory.updateDefinition, Result.success,
                 "Successfully updated workflow definition");
@@ -74,7 +74,7 @@ public class WorkflowController extends 
     @RequestMapping(method = RequestMethod.GET, value = "/tasks")
     public ModelAndView getDefinedTasks() throws WorkflowException {
 
-        List<String> definedTasks = wfAdapter.getDefinedTasks();
+        List<String> definedTasks = uwfAdapter.getDefinedTasks();
 
         auditManager.audit(Category.workflow, WorkflowSubCategory.getDefinedTasks, Result.success,
                 "Successfully got the list of defined workflow tasks: " + definedTasks.size());

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/sync/SyncopeSyncResultHanlder.java
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/sync/SyncopeSyncResultHanlder.java?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/sync/SyncopeSyncResultHanlder.java (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/sync/SyncopeSyncResultHanlder.java Mon Nov 12 11:53:36 2012
@@ -107,7 +107,7 @@ public class SyncopeSyncResultHanlder im
      * User workflow adapter.
      */
     @Autowired
-    private UserWorkflowAdapter wfAdapter;
+    private UserWorkflowAdapter uwfAdapter;
 
     /**
      * Propagation Manager.
@@ -346,7 +346,7 @@ public class SyncopeSyncResultHanlder im
                 }
                 // --------------------------
 
-                WorkflowResult<Map.Entry<Long, Boolean>> created = wfAdapter.create(userTO, true, enabled);
+                WorkflowResult<Map.Entry<Long, Boolean>> created = uwfAdapter.create(userTO, true, enabled);
 
                 List<PropagationTask> tasks = propagationManager.getCreateTaskIds(created, userTO.getPassword(),
                         userTO.getVirtualAttributes(), Collections.singleton(syncTask.getResource().getName()));
@@ -401,7 +401,7 @@ public class SyncopeSyncResultHanlder im
                     result.setUsername(userMod.getUsername());
 
                     if (!dryRun) {
-                        WorkflowResult<Map.Entry<Long, Boolean>> updated = wfAdapter.update(userMod);
+                        WorkflowResult<Map.Entry<Long, Boolean>> updated = uwfAdapter.update(userMod);
 
                         List<PropagationTask> tasks = propagationManager.getUpdateTaskIds(updated,
                                 userMod.getPassword(), userMod.getVirtualAttributesToBeRemoved(),
@@ -469,7 +469,7 @@ public class SyncopeSyncResultHanlder im
                     }
 
                     try {
-                        wfAdapter.delete(userId);
+                        uwfAdapter.delete(userId);
                     } catch (Exception e) {
                         result.setStatus(AbstractTaskJob.Status.FAILURE);
                         result.setMessage(e.getMessage());

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflow.properties
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflow.properties?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflow.properties (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflow.properties Mon Nov 12 11:53:36 2012
@@ -14,5 +14,5 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-wfAdapter=org.apache.syncope.core.workflow.user.activiti.ActivitiUserWorkflowAdapter
+uwfAdapter=org.apache.syncope.core.workflow.user.activiti.ActivitiUserWorkflowAdapter
 jobExecutorActivate=true

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflowContext.xml
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflowContext.xml?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflowContext.xml (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/resources/workflowContext.xml Mon Nov 12 11:53:36 2012
@@ -27,7 +27,7 @@ under the License.
     <constructor-arg value="${adminUser}"/>
   </bean>
     
-  <bean id="wfAdapter" class="${wfAdapter}"/>
+  <bean id="uwfAdapter" class="${uwfAdapter}"/>
 
   <bean id="syncopeActivitiUserManager" class="org.apache.syncope.core.workflow.user.activiti.SyncopeUserManager"/>
   <bean id="syncopeActivitiGroupManager" class="org.apache.syncope.core.workflow.user.activiti.SyncopeGroupManager"/>

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflow.properties
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflow.properties?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflow.properties (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflow.properties Mon Nov 12 11:53:36 2012
@@ -14,5 +14,5 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-wfAdapter=org.apache.syncope.core.workflow.NoOpUserWorkflowAdapter
+uwfAdapter=org.apache.syncope.core.workflow.user.NoOpUserWorkflowAdapter
 jobExecutorActivate=false
\ No newline at end of file

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflowContext.xml
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflowContext.xml?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflowContext.xml (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/noopworkflow/workflowContext.xml Mon Nov 12 11:53:36 2012
@@ -27,7 +27,7 @@ under the License.
     <constructor-arg value="${adminUser}"/>
   </bean>
     
-  <bean id="wfAdapter" class="${wfAdapter}"/>
+  <bean id="uwfAdapter" class="${uwfAdapter}"/>
 
   <bean id="velocityEngine" class="org.springframework.ui.velocity.VelocityEngineFactoryBean">
     <property name="velocityProperties">

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/workflow.properties
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/workflow.properties?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/workflow.properties (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/test/resources/workflow.properties Mon Nov 12 11:53:36 2012
@@ -14,5 +14,5 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-wfAdapter=org.apache.syncope.core.workflow.user.activiti.ActivitiUserWorkflowAdapter
+uwfAdapter=org.apache.syncope.core.workflow.user.activiti.ActivitiUserWorkflowAdapter
 jobExecutorActivate=false
--- incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/UserController.java (original)
+++ incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/UserController.java Mon Nov 12 11:53:36 2012
@@ -96,7 +96,7 @@ public class UserController {
     private UserDataBinder userDataBinder;
 
     @Autowired
-    private UserWorkflowAdapter wfAdapter;
+    private UserWorkflowAdapter uwfAdapter;
 
     @Autowired
     private PropagationManager propagationManager;
@@ -289,7 +289,7 @@ public class UserController {
             throw new UnauthorizedRoleException(requestRoleIds);
         }
 
-        WorkflowResult<Map.Entry<Long, Boolean>> created = wfAdapter.create(userTO);
+        WorkflowResult<Map.Entry<Long, Boolean>> created = uwfAdapter.create(userTO);
 
         List<PropagationTask> tasks = propagationManager.getCreateTaskIds(
                 created, userTO.getPassword(), userTO.getVirtualAttributes());
@@ -339,7 +339,7 @@ public class UserController {
 
         LOG.debug("User update called with {}", userMod);
 
-        WorkflowResult<Map.Entry<Long, Boolean>> updated = wfAdapter.update(userMod);
+        WorkflowResult<Map.Entry<Long, Boolean>> updated = uwfAdapter.update(userMod);
 
         List<PropagationTask> tasks = propagationManager.getUpdateTaskIds(updated, userMod.getPassword(), userMod.
                 getVirtualAttributesToBeRemoved(), userMod.getVirtualAttributesToBeUpdated(), null);
@@ -528,7 +528,7 @@ public class UserController {
 
         LOG.debug("About to execute {} on {}", taskId, userTO.getId());
 
-        WorkflowResult<Long> updated = wfAdapter.execute(userTO, taskId);
+        WorkflowResult<Long> updated = uwfAdapter.execute(userTO, taskId);
 
         List<PropagationTask> tasks = propagationManager.getUpdateTaskIds(new WorkflowResult<Map.Entry<Long, Boolean>>(
                 new DefaultMapEntry(updated.getResult(), null), updated.getPropByRes(), updated.getPerformedTasks()));
@@ -551,7 +551,7 @@ public class UserController {
     @RequestMapping(method = RequestMethod.GET, value = "/workflow/form/list")
     @Transactional(readOnly = true, rollbackFor = {Throwable.class})
     public List<WorkflowFormTO> getForms() {
-        List<WorkflowFormTO> forms = wfAdapter.getForms();
+        List<WorkflowFormTO> forms = uwfAdapter.getForms();
 
         auditManager.audit(Category.user, UserSubCategory.getForms, Result.success,
                 "Successfully list workflow forms: " + forms.size());
@@ -566,7 +566,7 @@ public class UserController {
             throws UnauthorizedRoleException, NotFoundException, WorkflowException {
 
         SyncopeUser user = userDataBinder.getUserFromId(userId);
-        WorkflowFormTO result = wfAdapter.getForm(user.getWorkflowId());
+        WorkflowFormTO result = uwfAdapter.getForm(user.getWorkflowId());
 
         auditManager.audit(Category.user, UserSubCategory.getFormForUser, Result.success,
                 "Successfully read workflow form for user: " + user.getUsername());
@@ -580,7 +580,7 @@ public class UserController {
     public WorkflowFormTO claimForm(@PathVariable("taskId") final String taskId)
             throws NotFoundException, WorkflowException {
 
-        WorkflowFormTO result = wfAdapter.claimForm(taskId,
+        WorkflowFormTO result = uwfAdapter.claimForm(taskId,
                 SecurityContextHolder.getContext().getAuthentication().getName());
 
         auditManager.audit(Category.user, UserSubCategory.claimForm, Result.success,
@@ -597,7 +597,7 @@ public class UserController {
 
         LOG.debug("About to process form {}", form);
 
-        WorkflowResult<Map.Entry<Long, String>> updated = wfAdapter.submitForm(form, SecurityContextHolder.getContext().
+        WorkflowResult<Map.Entry<Long, String>> updated = uwfAdapter.submitForm(form, SecurityContextHolder.getContext().
                 getAuthentication().getName());
 
         List<PropagationTask> tasks = propagationManager.getUpdateTaskIds(new WorkflowResult<Map.Entry<Long, Boolean>>(
@@ -624,11 +624,11 @@ public class UserController {
         WorkflowResult<Long> updated;
         if (performLocally) {
             if ("suspend".equals(task)) {
-                updated = wfAdapter.suspend(user.getId());
+                updated = uwfAdapter.suspend(user.getId());
             } else if ("reactivate".equals(task)) {
-                updated = wfAdapter.reactivate(user.getId());
+                updated = uwfAdapter.reactivate(user.getId());
             } else {
-                updated = wfAdapter.activate(user.getId(), token);
+                updated = uwfAdapter.activate(user.getId(), token);
             }
         } else {
             updated = new WorkflowResult<Long>(user.getId(), null, task);
@@ -664,7 +664,7 @@ public class UserController {
             throws NotFoundException, WorkflowException, PropagationException, UnauthorizedRoleException {
         // Note here that we can only notify about "delete", not any other
         // task defined in workflow process definition: this because this
         // information could only be available after wfAdapter.delete(), which
         // will also effectively remove user from db, thus making virtually
         // impossible by NotificationManager to fetch required user information
         notificationManager.createTasks(userId, Collections.singleton("delete"));
@@ -696,7 +696,7 @@ public class UserController {
             }
         });
 
-        wfAdapter.delete(userId);
+        uwfAdapter.delete(userId);
 
         auditManager.audit(Category.user, UserSubCategory.delete, Result.success,
                 "Successfully deleted user: " + userTO.getUsername());
@@ -664,7 +664,7 @@ public class UserController {
         // Note here that we can only notify about "delete", not any other
         // task defined in workflow process definition: this because this
-        // information could only be available after wfAdapter.delete(), which
+        // information could only be available after uwfAdapter.delete(), which
         // will also effectively remove user from db, thus making virtually
         // impossible by NotificationManager to fetch required user information

Modified: incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/WorkflowController.java
URL: http://svn.apache.org/viewvc/incubator/syncope/branches/DEV_ROLE_PROVISIONING/core/src/main/java/org/apache/syncope/core/rest/controller/WorkflowController.java?rev=1408258&r1=1408257&r2=1408258&view=diff
==============================================================================